@@ -135,6 +135,8 @@ class Window:
                             '^R': 'reload-tasks',
                             'u': 'open-url',
                             '>': 'delegate',
+                            'L': 'load-template',
+                            'S': 'save-template',
                             'l': 'load-search',
                             's': 'save-search',
                             '?': 'show-help',
@@ -202,6 +204,8 @@ class Window:
                           'search': self.do_start_search,
                           'search-context': self.do_search_context,
                           'search-project': self.do_search_project,
+                          'load-template': self.do_load_template,
+                          'save-template': self.do_save_template,
                           'load-search': self.do_load_search,
                           'save-search': self.do_save_search,
                           'first-item': self.do_go_first_task,
@@ -225,6 +229,8 @@ class Window:
                            'half-page-down': 'Half page down',
                            'search': 'Search',
                            'open-url': 'Open URL',
+                           'load-template': 'Load task template',
+                           'save-template': 'Save task as template',
                            'load-search': 'Load search',
                            'save-search': 'Save search',
                            'search-context': 'Search for context of this task',
@@ -274,6 +280,7 @@ class Window:
         self.task_lines = []
         self.max_widths = {}
         self.selected_task = -1
+        self.selected_template = None
         self.scroll_offset = 0
         self.must_repaint = True
         self.sort_order = utils.build_sort_order(common.DEFAULT_SORT_ORDER)
@@ -1303,6 +1310,10 @@ class Window:
             today = datetime.datetime.now().strftime(Task.DATE_FMT) + ' '
         if self.create_from_search:
             today += utils.create_from_search(self.search)
+        if self.selected_template is not None:
+            if not today.endswith(' '):
+                today += ' '
+            today += self.selected_template
         text = None
         source = None
         text, source = self.read_text(y, 4, self.dim[1]-8, today,
@@ -1361,6 +1372,44 @@ class Window:
                                       self.color(common.SETTING_COL_ERROR))
             self.update_tasks()
 
+    def do_load_template(self):
+        templates = utils.parse_templates()
+        if len(templates) == 0:
+            return
+        names = ['None'] + [name for name in sorted(templates.keys())]
+        name = self.select_one(names, tr('Load Template'), autoselect=False)
+        if names is not None and name in templates:
+            self.selected_template = templates[name]
+        elif name == 'None':
+            self.selected_template = None
+
+    def do_save_template(self):
+        y = curses.LINES//2 - 1
+        frame = curses.newwin(3, curses.COLS-6, y, 3)
+        frame.bkgdset(' ', self.color(common.SETTING_COL_NORMAL))
+        frame.erase()
+        frame.border()
+        label = tr('Save Template')
+        if curses.COLS-8 > len(label):
+            frame.addstr(0, 2, f'┤{label}├')
+        frame.refresh()
+
+        text = self.read_text(y+1, 4, curses.COLS-8, '')
+
+        if text is not None and len(text.strip()) > 0:
+            templates = utils.parse_templates()
+
+            if not (len(self.filtered_tasks) == 0 or self.selected_task >= len(self.filtered_tasks)):
+                task, source = self.filtered_tasks[self.selected_task]
+                raw = str(task).strip().split(' ')
+                if len(raw) > 1:
+                    raw = ' '.join(raw[1:]) #remove creation date
+                    templates[text] = raw
+                    utils.save_templates(templates)
+
+        frame.erase()
+        del frame
+
     def do_load_search(self):
         searches = utils.parse_searches()
         if len(searches) == 0:
@@ -1498,7 +1547,7 @@ class Window:
         nav_fncs = ['next-item', 'prev-item', 'half-page-up', 'half-page-down',
                     'first-item', 'last-item', 'jump-to']
         edt_fncs = ['toggle-hidden', 'toggle-done', 'edit-task', 'create-task',
-                    'toggle-tracking', 'delegate']
+                    'toggle-tracking', 'delegate', 'save-template', 'load-template']
         search_fncs = ['search', 'load-search', 'save-search', 'search-context', 'search-project']
         meta_fncs = ['show-help', 'open-manual', 'quit', 'cancel', 'refresh-screen',
                      'reload-tasks']
